/**
 * Keeps track of elapsed time.
 *
 * ```ts
 * const stopwatch = new Stopwatch();
 * // do some stuff that should be included in time
 * stopwatch.stop();
 * // do some more stuff that should not
 * stopwatch.start();
 * // do more stuff that should be timed
 * console.log(`important stuff took ${stopwatch}`);
 * ```
 */
export declare class Stopwatch {
    #private;
    /**
     * @param running whether the stopwatch is started immediately when constructed
     * @param previouslyElapsed milliseconds to be added to the total
     */
    constructor({ running, previouslyElapsed }?: {
        running?: boolean | undefined;
        previouslyElapsed?: number | undefined;
    });
    /**
     * Starts adding elapsed time to the total.
     */
    start(): void;
    /**
     * Stops adding elapsed time to the total.
     */
    stop(): void;
    /**
     * @returns the total number of milliseconds added to the total so far.
     */
    getElapsed(): number;
    /**
     * @param units see {@link elapsedToString}
     */
    toString(units?: string[]): string;
}
